@@ -33,7 +33,7 @@ module Gem2Deb
       Dir.chdir(source_dir) do
         load_gemspec
       end
-      set_gemspec_date
+      populate_gemspec_fields
       sort_filenames
     end
 
@@ -156,10 +156,15 @@ module Gem2Deb
       spec
     end
 
-    def set_gemspec_date
-      if @gemspec && File.exist?('debian/changelog')
+    def populate_gemspec_fields
+      return unless @gemspec
+      if File.exist?('debian/changelog')
         @gemspec.date = Date.parse(`dpkg-parsechangelog -SDate`.strip)
       end
+      if @gemspec.respond_to?(:rubyforge_project) # ruby2.5 and earlier
+        # This field is deprecated in ruby2.7, and ignored by it.
+        @gemspec.rubyforge_project = nil
+      end
     end
 
     def sort_filenames
